@@ -1,3 +1,3 @@
 require "test/unit"
-require_relative "core_assertions"
+require "core_assertions"
 Test::Unit::TestCase.include Test::Unit::CoreAssertions
